@@ -1,12 +1,13 @@
-version = (0, 9, 4)
+version = (0, 9, 5)
 
 
-def register(cls, config=None):
+def register(cls, **kwargs):
     from basky.config import BasketRegistry, BasketConfig
     # create a blank configuration
+    config = kwargs.get('config', None)
     if config is None:
         config = BasketConfig()
-        for k,v in kwargs.items():
+        for k, v in kwargs.items():
             setattr(config, k, v)
     # generate a key for the class
     key = '%s_%s' % (cls._meta.app_label, cls._meta.module_name)
@@ -14,13 +15,13 @@ def register(cls, config=None):
     # now add it to the registry
     BasketRegistry._registry[key] = config
 
-#
+
 # return a formatted version string
 def get_version():
     """returns a pep complient version number"""
     return '.'.join(str(i) for i in version)
 
-#
+
 # do the autodiscover stuff
 def autodiscover():
     """
@@ -29,10 +30,7 @@ def autodiscover():
     import copy
     from django.conf import settings
     from django.utils.importlib import import_module
-    from django.utils.module_loading import module_has_submodule
-    from basky.forms import BasketForm
-    from basky.models import Basket
-    
+
     for app in settings.INSTALLED_APPS:
         try:
             mod = import_module(app)
